@@ -1,6 +1,6 @@
 package Code::TidyAll::Plugin::JSBeautify;
 BEGIN {
-  $Code::TidyAll::Plugin::JSBeautify::VERSION = '0.09';
+  $Code::TidyAll::Plugin::JSBeautify::VERSION = '0.10';
 }
 use IPC::System::Simple qw(run);
 use Moo;
@@ -26,7 +26,7 @@ Code::TidyAll::Plugin::JSBeautify - use js-beautify with tidyall
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -54,7 +54,11 @@ Do not confuse this with the C<jsbeautify> package (without the dash).
 
 =item argv
 
-Arguments to pass to js-beautfy
+Arguments to pass to js-beautify
+
+=item cmd
+
+Full path to js-beautify
 
 =back
 
